@@ -438,7 +438,7 @@ int Incremental(char *devname, int verbose, int runstop,
 	/* 7/ Is there enough devices to possibly start the array? */
 	/* 7a/ if not, finish with success. */
 	if (info.array.level == LEVEL_CONTAINER) {
-		char *devname = NULL;
+		int devnum = devnum; /* defined and used iff ->external */
 		/* Try to assemble within the container */
 		map_unlock(&map);
 		sysfs_uevent(&info, "change");
@@ -448,7 +448,7 @@ int Incremental(char *devname, int verbose, int runstop,
 				chosen_name, info.array.working_disks);
 		wait_for(chosen_name, mdfd);
 		if (st->ss->external)
-			devname = devnum2devname(fd2devnum(mdfd));
+			devnum = fd2devnum(mdfd);
 		close(mdfd);
 		sysfs_free(sra);
 		rv = Incremental(chosen_name, verbose, runstop,
@@ -460,10 +460,8 @@ int Incremental(char *devname, int verbose, int runstop,
 			rv = 0;
 		/* after spare is added, ping monitor for external metadata
 		 * so that it can eg. try to rebuild degraded array */
-		if (st->ss->external) {
-			ping_monitor(devname);
-			free(devname);
-		}
+		if (st->ss->external)
+			ping_monitor_by_id(devnum);
 		return rv;
 	}
 
@@ -1471,7 +1469,9 @@ static int Incremental_container(struct supertype *st, char *devname,
 	if (list->array.state & (1<<MD_SB_BBM_ERRORS)) {
 		fprintf(stderr, Name ": BBM log found in metadata. "
 					"Cannot activate array(s).\n");
-		list = NULL;
+		/* free container data and exit */
+		sysfs_free(list);
+		return 2;
 	}
 
 	for (ra = list ; ra ; ra = ra->next) {
@@ -1553,7 +1553,8 @@ static int Incremental_container(struct supertype *st, char *devname,
 		}
 
 		assemble_container_content(st, mdfd, ra, runstop,
-					   chosen_name, verbose);
+					   chosen_name, verbose, NULL);
+		close(mdfd);
 	}
 
 	/* Now move all suitable spares from spare container */
